libatframe_utils_template

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 11, 2026 License: MIT Imports: 9 Imported by: 0

Documentation

Overview

Copyright 2025 atframework

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func TemplateFuncMap

func TemplateFuncMap() template.FuncMap

funcMap returns a mapping of all of the functions that Engine has.

Because some functions are late-bound (e.g. contain context-sensitive data), the functions may not all perform identically outside of an Engine as they will inside of an Engine.

Known late-bound functions:

  • "include"
  • "tpl"

These are late-bound in Engine.Render(). The version included in the FuncMap is a placeholder.

Types

This section is empty.

Jump to